@@ -10,8 +10,8 @@ if test -r /etc/profile; then
 	. /etc/profile
 fi
 
-if test -r $HOME/.profile; then
-	. $HOME/.profile
+if test -r ~/.profile; then
+	. ~/.profile
 fi
 
 test -x /etc/X11/Xsession && exec /etc/X11/Xsession
